========================================
``psyclone.psyir.nodes.kernel_schedule``
========================================

.. automodule:: psyclone.psyir.nodes.kernel_schedule

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.kernel_schedule


Classes
=======

- :py:class:`KernelSchedule`:
  A KernelSchedule is the parent node of the PSyIR for Kernel source code.


.. autoclass:: KernelSchedule
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: KernelSchedule
      :parts: 1
